@@ -5,7 +5,7 @@ from functools import lru_cache
 from typing import Any, Iterator, List, Optional
 
 from mkapi.core.base import Base, Object
-from mkapi.core.object import from_object, get_object
+from mkapi.core.object import from_object, get_object, get_sourcefiles
 from mkapi.core.tree import Tree
 
 
@@ -13,6 +13,10 @@ from mkapi.core.tree import Tree
 class Node(Tree):
     """Node class represents an object.
 
+    Args:
+        sourcefile_index: If `obj` is a member of class, this value is the index of
+            unique source files given by `mro()` of the class. Otherwise, 0.
+
     Attributes:
         parent: Parent Node instance.
         members: Member Node instances.
@@ -20,6 +24,7 @@ class Node(Tree):
 
     parent: Optional["Node"] = field(default=None, init=False)
     members: List["Node"] = field(init=False)
+    sourcefile_index: int = 0
 
     def __post_init__(self):
         super().__post_init__()
@@ -116,55 +121,72 @@ def get_kind(obj) -> str:
     return ""
 
 
-def is_member(name: str, obj: Any, sourcefile: str) -> bool:
+def is_member(name: str, obj: Any, sourcefiles: List[str]) -> int:
+    """Returns an integer thats indicates if `obj` is a member or not.
+
+    * $-1$ : Is not a member.
+    * $>0$ : Is a member. If the value is larger than 0, `obj` is defined
+        in different file and the value is corresponding to the index of unique
+        source files of superclasses.
+
+    Args:
+        name: Object name.
+        obj: Object
+        sourcefiles: Parent source files. If the parent is a class,
+            those of the superclasses should be included in the order
+            of `mro()`.
+    """
     if isinstance(obj, property):
-        return True
+        obj = obj.fget
     if name in ["__func__", "__self__"]:
-        return False
+        return -1
     if name.startswith("_"):
         if not name.startswith("__") or not name.endswith("__"):
-            return False
+            return -1
     if not get_kind(obj):
-        return False
+        return -1
     try:
-        source = inspect.getsourcefile(obj)
+        sourcefile = inspect.getsourcefile(obj)
     except TypeError:
-        return False
-    if sourcefile and source != sourcefile:
-        return False
-    return True
+        return -1
+    if not sourcefiles:
+        return 0
+    for sourcefile_index, parent_sourcefile in enumerate(sourcefiles):
+        if sourcefile == parent_sourcefile:
+            return sourcefile_index
+    return -1
 
 
-def get_members(obj) -> List[Node]:
+def get_members(obj: Any) -> List[Node]:
     if inspect.ismodule(obj) or isinstance(obj, property):
         return []
 
-    try:
-        sourcefile = inspect.getsourcefile(obj) or ""
-    except TypeError:
-        sourcefile = ""
+    sourcefiles = get_sourcefiles(obj)
     members = []
     for name, obj in inspect.getmembers(obj):
-        if is_member(name, obj, sourcefile) and not from_object(obj):
-            member = get_node(obj)
+        sourcefile_index = is_member(name, obj, sourcefiles)
+        if sourcefile_index != -1 and not from_object(obj):
+            member = get_node(obj, sourcefile_index)
             if member.docstring:
                 members.append(member)
-    return sorted(members, key=lambda x: x.lineno)
+    return sorted(members, key=lambda x: (-x.sourcefile_index, x.lineno))
 
 
 USE_CACHE = True
 
 
 @lru_cache(maxsize=1000)
-def _get_node(obj) -> Node:
-    return Node(obj)
+def _get_node(obj, sourcefile_index) -> Node:
+    return Node(obj, sourcefile_index)
 
 
-def get_node(name) -> Node:
+def get_node(name, sourcefile_index: int = 0) -> Node:
     """Returns a Node instace by name or object.
 
     Args:
         name: Object name or object itself.
+        sourcefile_index: If `obj` is a member of class, this value is the index of
+            unique source files given by `mro()` of the class. Otherwise, 0.
     """
     if isinstance(name, str):
         obj = get_object(name)
@@ -172,6 +194,6 @@ def get_node(name) -> Node:
         obj = name
 
     if USE_CACHE:
-        return _get_node(obj)
+        return _get_node(obj, sourcefile_index)
     else:
-        return Node(obj)
+        return Node(obj, sourcefile_index)
